@@ -1,7 +1,8 @@
 #!/usr/bin/perl -w
 
+
 #-----------------------------------------------------------------------
-# Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+# Copyright (C) 2002-2005 Jrn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Event::RPC, which is free software; you can
@@ -11,7 +12,7 @@
 use strict;
 
 use strict;
-
+use lib qw( lib ../lib examples .);
 use Event::RPC::Server;
 use Event::RPC::Logger;
 use Getopt::Std;
@@ -36,10 +37,10 @@ Options:
 __EOU
 
 sub HELP_MESSAGE {
-    my ($fh) = @_;
-    $fh ||= \*STDOUT;
-    print $fh $USAGE;
-    exit;
+	my ($fh) = @_;
+	$fh ||= \*STDOUT;
+	print $fh $USAGE;
+	exit;
 }
 
 main: {
@@ -50,44 +51,44 @@ main: {
 
     my %ssl_args;
     if ( $opts{s} ) {
-        %ssl_args = (
-            ssl => 1,
-            ssl_key_file  => 'ssl/server.key',
-            ssl_cert_file => 'ssl/server.crt',
-            ssl_passwd_cb => sub { 'eventrpc' },
-        );
-        if ( not -f 'ssl/server.key' ) {
-            chdir ("examples");
-            if ( not -f 'ssl/server.key' ) {
-                print "please execute from toplevel or examples/ directory\n";
-                exit 1;
-            }
-        }
+      %ssl_args = (
+        ssl => 1,
+	ssl_key_file  => 'ssl/server.key',
+	ssl_cert_file => 'ssl/server.crt',
+	ssl_passwd_cb => sub { 'eventrpc' },
+      );
+      if ( not -f 'ssl/server.key' ) {
+        chdir ("examples");
+	if ( not -f 'ssl/server.key' ) {
+	  print "please execute from toplevel or examples/ directory\n";
+	  exit 1;
+	}
+      }
     }
 
     my %auth_args;
     if ( $opts{a} ) {
-        my ($user, $pass) = split(":", $opts{a}); 
-        $pass = Event::RPC->crypt($user, $pass);
-        %auth_args = (
-            auth_required    => 1,
-            auth_passwd_href => { $user => $pass },
-        );
+      my ($user, $pass) = split(":", $opts{a}); 
+      $pass = Event::RPC->crypt($user, $pass);
+      %auth_args = (
+	auth_required    => 1,
+	auth_passwd_href => { $user => $pass },
+      );
     }
 
     #-- Create a logger object
     my $logger = Event::RPC::Logger->new (
-        min_level => ($opts{l}||4),
-        fh_lref   => [ \*STDOUT ],
+	    min_level => ($opts{l}||4),
+	    fh_lref   => [ \*STDOUT ],
     );
 
     #-- Create a loop object
     my $loop;
     my $loop_module = $opts{L};
     if ( $loop_module ) {
-        eval "use $loop_module";
-        die $@ if $@;
-        $loop = $loop_module->new();
+	    eval "use $loop_module";
+	    die $@ if $@;
+	    $loop = $loop_module->new();
     }
     
     #-- Host parameter
@@ -96,27 +97,28 @@ main: {
     #-- Create a Server instance and declare the
     #-- exported interface
     my $server = Event::RPC::Server->new (
-        name                => "test daemon",
-        host                => $host,
-        port                => 5555,
-        logger              => $logger,
-        loop                => $loop,
-        start_log_listener  => 1,
-        auto_reload_modules => 1,
-        message_formats     => [qw/ SERL CBOR JSON STOR /],
-        %auth_args,
-        %ssl_args,
-        classes => {
-            'Test_class' => {
-                new       => '_constructor',
-                set_data  => 1,
-                get_data  => 1,
-                hello     => 1,
-                quit      => 1,
-            },
-        },
+      name                => "test daemon",
+      host		  => $host,
+      port                => 5555,
+      logger              => $logger,
+      loop                => $loop,
+      start_log_listener  => 1,
+      auto_reload_modules => 1,
+      %auth_args,
+      %ssl_args,
+      classes => {
+	'Test_class' => {
+	  new       => '_constructor',
+	  set_data  => 1,
+	  get_data  => 1,
+	  hello     => 1,
+	  quit	    => 1,
+	},
+      },
     );
 
     #-- Start the server resp. the Event loop.
     $server->start;
 }
+
+
