@@ -1,5 +1,6 @@
+
 #-----------------------------------------------------------------------
-# Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+# Copyright (C) 2002-2006 Jrn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Event::RPC, which is free software; you can
@@ -11,8 +12,6 @@ package Event::RPC::Loop::Event;
 use base qw( Event::RPC::Loop );
 
 use strict;
-use utf8;
-
 use Event;
 
 sub add_io_watcher {
@@ -26,7 +25,6 @@ sub add_io_watcher {
         cb        => $cb,
         desc      => $desc,
         reentrant => 0,
-        parked    => 0,
     );
 }
 
@@ -85,7 +83,7 @@ sub leave {
 
 __END__
 
-=encoding utf8
+=encoding latin1
 
 =head1 NAME
 
@@ -113,11 +111,11 @@ Event::RPC::Loop for details.
 
 =head1 AUTHORS
 
-  Jörn Reder <joern AT zyn.de>
+  Jrn Reder <joern at zyn dot de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+Copyright (C) 2002-2006 by Joern Reder, All Rights Reserved.
 
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
