@@ -1,4 +1,3 @@
-# $Id: Server.pm,v 1.14 2011-03-08 11:50:56 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2002-2006 Jrn Reder <joern AT zyn.de>.
@@ -37,6 +36,7 @@ sub get_ssl                     { shift->{ssl}                          }
 sub get_ssl_key_file            { shift->{ssl_key_file}                 }
 sub get_ssl_cert_file           { shift->{ssl_cert_file}                }
 sub get_ssl_passwd_cb           { shift->{ssl_passwd_cb}                }
+sub get_ssl_opts                { shift->{ssl_opts}                     }
 sub get_auth_required           { shift->{auth_required}                }
 sub get_auth_passwd_href        { shift->{auth_passwd_href}             }
 sub get_auth_module             { shift->{auth_module}                  }
@@ -63,6 +63,7 @@ sub set_ssl                     { shift->{ssl}                  = $_[1] }
 sub set_ssl_key_file            { shift->{ssl_key_file}         = $_[1] }
 sub set_ssl_cert_file           { shift->{ssl_cert_file}        = $_[1] }
 sub set_ssl_passwd_cb           { shift->{ssl_passwd_cb}        = $_[1] }
+sub set_ssl_opts                { shift->{ssl_opts}             = $_[1] }
 sub set_auth_required           { shift->{auth_required}        = $_[1] }
 sub set_auth_passwd_href        { shift->{auth_passwd_href}     = $_[1] }
 sub set_auth_module             { shift->{auth_module}          = $_[1] }
@@ -75,13 +76,23 @@ sub set_active_connection       { shift->{active_connection}    = $_[1] }
 my $INSTANCE;
 sub instance { $INSTANCE }
 
+sub get_max_packet_size {
+    return Event::RPC::Message->get_max_packet_size;
+}
+
+sub set_max_packet_size {
+    my $class = shift;
+    my ($value) = @_;
+    Event::RPC::Message->set_max_packet_size($value);
+}
+
 sub new {
     my $class = shift;
     my %par = @_;
     my  ($host, $port, $classes, $name, $logger, $start_log_listener) =
     @par{'host','port','classes','name','logger','start_log_listener'};
-    my  ($ssl, $ssl_key_file, $ssl_cert_file, $ssl_passwd_cb) =
-    @par{'ssl','ssl_key_file','ssl_cert_file','ssl_passwd_cb'};
+    my  ($ssl, $ssl_key_file, $ssl_cert_file, $ssl_passwd_cb, $ssl_opts) =
+    @par{'ssl','ssl_key_file','ssl_cert_file','ssl_passwd_cb','ssl_opts'};
     my  ($auth_required, $auth_passwd_href, $auth_module, $loop) =
     @par{'auth_required','auth_passwd_href','auth_module','loop'};
     my  ($connection_hook, $auto_reload_modules, $load_modules) =
@@ -123,6 +134,7 @@ sub new {
         ssl_key_file            => $ssl_key_file,
         ssl_cert_file           => $ssl_cert_file,
         ssl_passwd_cb           => $ssl_passwd_cb,
+        ssl_opts                => $ssl_opts,
 
         auth_required           => $auth_required,
         auth_passwd_href        => $auth_passwd_href,
@@ -178,25 +190,27 @@ sub setup_listeners {
         croak "ssl_key_file not set"  unless $self->get_ssl_key_file;
         croak "ssl_cert_file not set" unless $self->get_ssl_cert_file;
 
+        my $ssl_opts = $self->get_ssl_opts;
+
         $rpc_socket = IO::Socket::SSL->new (
-                Listen          => SOMAXCONN,
-                @LocalHost,
-                LocalPort       => $port,
-                Proto           => 'tcp',
-                ReuseAddr       => 1,
-                SSL_verify_mode => 0x00,
-                SSL_key_file    => $self->get_ssl_key_file,
-                SSL_cert_file   => $self->get_ssl_cert_file,
-                SSL_passwd_cb   => $self->get_ssl_passwd_cb,
+            Listen          => SOMAXCONN,
+            @LocalHost,
+            LocalPort       => $port,
+            Proto           => 'tcp',
+            ReuseAddr       => 1,
+            SSL_key_file    => $self->get_ssl_key_file,
+            SSL_cert_file   => $self->get_ssl_cert_file,
+            SSL_passwd_cb   => $self->get_ssl_passwd_cb,
+            ($ssl_opts?%{$ssl_opts}:()),
         ) or die "can't start SSL RPC listener: $IO::Socket::SSL::ERROR";
     }
     else {
         $rpc_socket = IO::Socket::INET->new (
-                Listen    => SOMAXCONN,
-                @LocalHost,
-                LocalPort => $port,
-                Proto     => 'tcp',
-                ReuseAddr => 1,
+            Listen    => SOMAXCONN,
+            @LocalHost,
+            LocalPort => $port,
+            Proto     => 'tcp',
+            ReuseAddr => 1,
         ) or die "can't start RPC listener: $!";
     }
 
@@ -412,6 +426,8 @@ sub print_object_register {
 
 __END__
 
+=encoding latin1
+
 =head1 NAME
 
 Event::RPC::Server - Simple API for event driven RPC servers
@@ -442,6 +458,7 @@ Event::RPC::Server - Simple API for event driven RPC servers
       ssl_key_file        => "server.key",
       ssl_cert_file       => "server.crt",
       ssl_passwd_cb       => sub { "topsecret" },
+      ssl_opts            => { ... },
 
       auth_required       => 1,
       auth_passwd_href    => { $user => Event::RPC->crypt($user,$pass) },
@@ -455,6 +472,7 @@ Event::RPC::Server - Simple API for event driven RPC servers
       connection_hook     => sub { ... },
   );
 
+  $server->set_max_packet_size(2*1024*1024*1024);
   $server->start;
 
   # and later from inside your server implementation
@@ -514,7 +532,7 @@ This is a hash ref with the following structure:
     ...
   },
 
-Each class which should be accessable for clients needs to
+Each class which should be accessible for clients needs to
 be listed here at the first level, assigned a hash of methods
 allowed to be called. Event::RPC disuinguishes three types
 of methods by classifying their return value:
@@ -607,6 +625,12 @@ password, e.g.
 But note: having the password in plaintext in your program code is
 insecure!
 
+=item B<ssl_opts>
+
+This optional parameter takes a hash reference of options
+passed to IO::Socket::SSL->new(...) to have more control
+over the server SSL listener. 
+
 =back
 
 =head2 AUTHENTICATION OPTIONS
@@ -756,7 +780,7 @@ and manage the main loop stuff on your own.
 
 By default the network listeners are bound to all interfaces
 in the system. Use the host option to bind to a specific
-interface, e.g. "localhost" if you efficently want to prevent
+interface, e.g. "localhost" if you efficiently want to prevent
 network clients from accessing your server.
 
 =item B<load_modules>
@@ -780,6 +804,8 @@ with two arguments: the Event::RPC::Connection object and
 a string containing either "connect" or "disconnect" depending
 what's currently happening with this connection.
 
+=back
+
 =head1 METHODS
 
 The following methods are publically available:
@@ -827,6 +853,22 @@ representing the connection resp. the client which currently
 requests method invocation. This is undef if no client call
 is active.
 
+=item $rpc_client->B<set_max_packet_size> ( $bytes )
+
+By default Event::RPC does not handle network packages which
+exceed 2 GB in size (was 4 MB with version 1.04 and earlier).
+
+You can change this value using this method at any time,
+but 4 GB is the maximum. An attempt of the server to send a
+bigger packet will be aborted and reported as an exception
+on the client and logged as an error message on the server.
+
+Note: you have to set the same value on client and server side!
+
+=item $rpc_client->B<get_max_packet_size>
+
+Returns the currently active max packet size.
+
 =back
 
 =head1 AUTHORS
